@@ -2,10 +2,17 @@ import os
 import time
 from datetime import timezone
 from jsoncustom import JsonCustom
+from dotenv import load_dotenv, dotenv_values
 from requestsgarant import (
     RequestsGarant, RequestsGarantTestBaseUrl, RequestsGarantTestEndpoint, RequestsGarantTestHeaders
 )
 
+main_env = load_dotenv()
+
+if 'PATH_TO_ENV' in dotenv_values(".env"):
+    load_dotenv(dotenv_path=os.environ.get('PATH_TO_ENV'))
+else:
+    load_dotenv(dotenv_path='C:\\config_bank_rko\\.env')
 
 inn_freedom = "Свободен"
 inn_busy = "Занят"
@@ -23,8 +30,8 @@ def get_rand_str(total: int):
 
 class Alfa(RequestsGarantTestHeaders):
     headers = {'Content-Type': 'application/json; charset=UTF-8'}
-    dict_key = None
-    dict_key_test = None
+    dict_key = {'API-key': os.environ.get('alfabank_dict_key')}
+    dict_key_test = {'API-key': 'aaaaaaaa-aaaa-aaaa-aaaa-aaaaaaaaaaaa'}
 
     def __init__(self, test=test):
         super().__init__()
@@ -33,7 +40,7 @@ class Alfa(RequestsGarantTestHeaders):
 
 
 class CityBankes:
-    cities_path = None
+    cities_path = os.environ.get('cities_path')
 
     def __init__(self):
         self.JC = JsonCustom(f'{self.cities_path}{self.__class__.__name__}.json')
@@ -120,8 +127,12 @@ class AlfaLead(Alfa):
 
 
 class VTBBigFather(RequestsGarant):
-    path_vtb_token = f'{os.path.abspath(os.curdir)}/vtb_api_token.json'
-    credits = None
+    path_vtb_token = f'{os.path.abspath(os.curdir)}/vtb_api_token.json'.replace('venv\Lib\site-packages/', '')
+    credits = {
+        'grant_type': os.environ.get('vtb_grant_type'),
+        'client_id': os.environ.get('vtb_client_id'),
+        'client_secret': os.environ.get('vtb_client_secret')
+    }
 
     def __init__(self):
         super().__init__()
@@ -207,7 +218,8 @@ class VTBScoring(VTBFather):
             if 'moreInformation' in self.response_json:
                 if self.response_json['moreInformation'] == 'URL Open error: Could not connect to endpoint' or \
                         self.response_json['moreInformation'] == 'Internal Server Error: ' \
-                                                                 'Assembly reference is required.':
+                                                                 'Assembly reference is required.' or \
+                        self.response_json['moreInformation'].find('<BackErr>') != -1:
                     self.resend_send = True
         return do_json_father
 
@@ -230,7 +242,7 @@ class VTBLead(VTBFather):
 class Open(RequestsGarantTestEndpoint):
     base_url = 'https://openpartners.ru/api/v2/request/'
     JSON_TEST_OPEN_BASE_DIR = f'{os.path.abspath(os.curdir)}/jsons/'
-    token = None
+    token = os.environ.get('open_token')
 
     def __init__(self):
         super().__init__()
@@ -361,7 +373,7 @@ class OpenLead(OpenLeadScoring):
 class Module(RequestsGarantTestBaseUrl):
     base_url = 'https://partner.modulbank.ru/public/'
     base_url_test = 'https://partnertest.modulbank.ru/public/'
-    tnx = None
+    tnx = os.environ.get('module_tnx')
 
     def __init__(self):
         super().__init__()
@@ -407,7 +419,7 @@ class ModuleLead(Module):
 
 
 class Tochka(RequestsGarant):
-    token = None
+    token = os.environ.get('tochka_token')
 
     def __init__(self, json):
         super().__init__()
@@ -432,6 +444,9 @@ class TochkaLead(Tochka):
     def do_json(self):
         if isinstance(self.response_json, list):
             if self.response_json:
+                if 'Не удалось определить пол' in self.response_json[0]:
+                    self.json['request'].update({'sex': 'M'})
+                    return self.get_rezult()
                 self.success = True
                 return self.response_json[0]
 
@@ -473,8 +488,8 @@ class TochkaAddDocs(Tochka):
 
 class MoeDelo(RequestsGarantTestHeaders):
     headers = {'Content-Type': 'application/json; charset=UTF-8'}
-    username = None
-    user_key = None
+    username = os.environ.get('moedelo_username')
+    user_key = os.environ.get('moedelo_user_key')
 
     def __init__(self, test=test):
         super().__init__()
@@ -529,6 +544,29 @@ class MoeDeloLead(MoeDelo):
             return self.response_json['RequestId']
 
 
+def get_url(mod):
+    return f"https://api.raiffeisen.ru/openapi-013-{mod}/corporate-leads-xs/app"
+
+
+class Raifazen(RequestsGarantTestBaseUrl):
+    endpoint = ''
+    base_url = get_url('opn')
+    base_url_test = get_url('snd')
+    token = os.environ.get('raifazen_token')
+    partner_id = os.environ.get('raifazen_partner_id')
+
+    def __init__(self, json, test=test):
+        super().__init__()
+        self.headers = {
+            'key': self.token,
+            'partnerID': self.partner_id
+        }
+
+        self.method = 'post'
+        self.test = test
+        self.json = json
+
+
 class PSBall:
     def __init__(self):
         self.test = test
@@ -539,7 +577,6 @@ class PSBall:
 
 
 class PSBToken(PSBall, RequestsGarant):
-
     def do_json(self):
         if 'data' in self.response_json:
             data = self.response_json['data']
@@ -561,8 +598,8 @@ class PSBParent(RequestsGarantTestBaseUrl):
 
 
 class PSB(PSBParent):
-    email = None
-    password = None
+    email = os.environ.get('psb_email')
+    password = os.environ.get('psb_password')
 
     def __init__(self, session, test=test):
         super().__init__(test)
